@@ -124,6 +124,42 @@ function(S=35,T=25,P=0,k1k2='x',pHscale="T",kSWS2scale=0,ktotal2SWS_P0=0)
     K1[is_m10_F] <- 10^(-pK1)  # K1 according to Millero et al. 2010 at Total scale
     pHsc[is_m10_F] <- "F"
 
+    # --------------------- K1 ---------------------------------------
+    #   first acidity constant:
+    #   [H^+] [HCO_3^-] / [CO2] = K_1
+    #
+    #   Waters, Millero, Woosley (Mar. Chem., 165, 66-67, 2014)
+
+    is_w14 <- k1k2 == "w14"
+    pK1o <- 6320.813/TK[is_w14] + 19.568224*log(TK[is_w14]) -126.34048
+
+    #   pH-scale: 'SWS scale'. mol/kg-soln
+    is_w14_SWS <- is_w14 & (pHscale=="SWS" | P>0)
+    A1 <- 13.409160*S[is_w14_SWS]^(0.5) + 0.031646*S[is_w14_SWS] - (5.1895e-5)*S[is_w14_SWS]^2
+    B1 <- -531.3642*S[is_w14_SWS]^(0.5) - 5.713*S[is_w14_SWS]
+    C1 <- -2.0669166*S[is_w14_SWS]^(0.5)
+    pK1 <- pK1o + A1 + B1/TK[is_w14_SWS] + C1*log(TK[is_w14_SWS])
+    K1[is_w14_SWS] <- 10^(-pK1)   # K1 according to Millero et al. 2010 at Seawater scale
+    pHsc[is_w14_SWS] <- "SWS" 
+
+    #   pH-scale: 'Total scale'. mol/kg-soln
+    is_w14_T <- is_w14 & (pHscale=="T" & P==0)
+    A1 <- 13.568513*S[is_w14_T]^(0.5) + 0.031645*S[is_w14_T] - (5.3834e-5)*S[is_w14_T]^2
+    B1 <- -539.2304*S[is_w14_T]^(0.5) - 5.635*S[is_w14_T]
+    C1 <- -2.0901396*S[is_w14_T]^(0.5)
+    pK1 <- pK1o + A1 + B1/TK[is_w14_T] + C1*log(TK[is_w14_T])
+    K1[is_w14_T] <- 10^(-pK1)   # K1 according to Millero et al. 2010 at Total scale 
+    pHsc[is_w14_T] <- "T"
+
+    #   pH-scale: 'Free scale'. mol/kg-soln
+    is_w14_F <- is_w14 & (pHscale=="F" & P==0)
+    A1 <- 5.592953*S[is_w14_F]^(0.5) + 0.028845*S[is_w14_F] - (6.388e-5)*S[is_w14_F]^2
+    B1 <- -225.7489*S[is_w14_F]^(0.5) - 4.761*S[is_w14_F]
+    C1 <- -0.8715109*S[is_w14_F]^(0.5)
+    pK1 <- pK1o + A1 + B1/TK[is_w14_F] + C1*log(TK[is_w14_F])
+    K1[is_w14_F] <- 10^(-pK1)  # K1 according to Millero et al. 2010 at Total scale
+    pHsc[is_w14_F] <- "F"
+
     ##----------------- Conversion from total to SWS scale
     ##                  if pressure correction needed
     ##                  or pH scale conversion required anyway
@@ -214,8 +250,9 @@ function(S=35,T=25,P=0,k1k2='x',pHscale="T",kSWS2scale=0,ktotal2SWS_P0=0)
     method <- rep(NA, nK)
     method[is_m06] <- "Millero et al. (2006)"
     method[is_m10] <- "Millero (2010)"
+    method[is_w14] <- "Waters et al. (2014)"
     method[is_r]   <- "Roy et al. (1993)"
-    method[! (is_m06 | is_m10 | is_r) ] <- "Luecker et al. (2000)"
+    method[! (is_m06 | is_m10 | is_w14 | is_r) ] <- "Luecker et al. (2000)"
 
     attr(K1,"unit") <- "mol/kg-soln"
     attr(K1,"pH scale") <- pHlabel
